from typing import Literal

GridColumnStartEnd = Literal[
    'auto',
    'span-1',
    'span-2',
    'span-3',
    'span-4',
    'span-5',
    'span-6',
    'span-7',
    'span-8',
    'span-9',
    'span-10',
    'span-11',
    'span-12',
    'span-full',
    'start-1',
    'start-2',
    'start-3',
    'start-4',
    'start-5',
    'start-6',
    'start-7',
    'start-8',
    'start-9',
    'start-10',
    'start-11',
    'start-12',
    'start-13',
    'start-auto',
    'end-1',
    'end-2',
    'end-3',
    'end-4',
    'end-5',
    'end-6',
    'end-7',
    'end-8',
    'end-9',
    'end-10',
    'end-11',
    'end-12',
    'end-13',
    'end-auto',
]
